# sushi-grpc-api

Protobuf for Sushi's gRPC API definition.

This repository is included as submodule by all the projects that uses Sushi's gRPC interface:
  * [Sushi](https://github.com/elk-audio/sushi)
  * [elkpy](https://github.com/elk-audio/elkpy)
  * [elkcpp](https://github.com/elk-audio/elkcpp)

## License
Sushi is licensed under Affero General Public License (“AGPLv3”). See [LICENSE](LICENSE.md) document for the full details of the license. For contributing code to Sushi, see [CONTRIBUTING.md](CONTRIBUTING.md).

Copyright 2017-2025 Modern Ancient Instruments Networked AB, dba Elk, Stockholm, Sweden.

